"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.mdb.opensearch.v1.auth_pb2
import yandex.cloud.mdb.opensearch.v1.backup_pb2
import yandex.cloud.mdb.opensearch.v1.cluster_pb2
import yandex.cloud.mdb.opensearch.v1.config.opensearch_pb2
import yandex.cloud.mdb.opensearch.v1.maintenance_pb2
import yandex.cloud.operation.operation_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster to return.

    To get the cluster ID, use a [ClusterService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___GetClusterRequest = GetClusterRequest

@typing.final
class ListClustersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list OpenSearch clusters in.

    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return.

    If the number of available results is larger than [page_size], the service returns
    a [ListClustersResponse.next_page_token] that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the [ListClustersResponse.next_page_token]
    returned by the previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.

    The expression must specify:

    1. The field name. Currently you can only use filtering with the [Cluster.name] field.

    2. An `=` operator.

    3. The value in double quotes (`"`). Must be 1-63 characters long and match the regular expression `[a-zA-Z0-9_-]+`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClustersRequest = ListClustersRequest

@typing.final
class ListClustersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests.

    If the number of results is larger than [ListClustersRequest.page_size], use the [next_page_token] as the value
    for the [ListClustersRequest.page_token] parameter in the next list request.

    Each subsequent list request has its own [next_page_token] to continue paging through the results.
    """
    @property
    def clusters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.opensearch.v1.cluster_pb2.Cluster]:
        """List of OpenSearch clusters."""

    def __init__(
        self,
        *,
        clusters: collections.abc.Iterable[yandex.cloud.mdb.opensearch.v1.cluster_pb2.Cluster] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["clusters", b"clusters", "next_page_token", b"next_page_token"]) -> None: ...

global___ListClustersResponse = ListClustersResponse

@typing.final
class CreateClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    CONFIG_SPEC_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create the OpenSearch cluster in."""
    name: builtins.str
    """Name of the OpenSearch cluster. The name must be unique within the folder."""
    description: builtins.str
    """Description of the OpenSearch cluster."""
    environment: yandex.cloud.mdb.opensearch.v1.cluster_pb2.Cluster.Environment.ValueType
    """Deployment environment of the OpenSearch cluster."""
    network_id: builtins.str
    """ID of the network to create the cluster in."""
    service_account_id: builtins.str
    """ID of the service account used to access Object Storage."""
    deletion_protection: builtins.bool
    """Determines whether the cluster is protected from being deleted."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the OpenSearch cluster as `key:value` pairs.
        For example, `"project": "mvp"` or `"source": "dictionary"`.
        """

    @property
    def config_spec(self) -> global___ConfigCreateSpec:
        """OpenSearch cluster configuration."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups."""

    @property
    def maintenance_window(self) -> yandex.cloud.mdb.opensearch.v1.maintenance_pb2.MaintenanceWindow:
        """Cluster maintenance window. Should be defined by either one of the two options."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        environment: yandex.cloud.mdb.opensearch.v1.cluster_pb2.Cluster.Environment.ValueType = ...,
        config_spec: global___ConfigCreateSpec | None = ...,
        network_id: builtins.str = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        service_account_id: builtins.str = ...,
        deletion_protection: builtins.bool = ...,
        maintenance_window: yandex.cloud.mdb.opensearch.v1.maintenance_pb2.MaintenanceWindow | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config_spec", b"config_spec", "maintenance_window", b"maintenance_window"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config_spec", b"config_spec", "deletion_protection", b"deletion_protection", "description", b"description", "environment", b"environment", "folder_id", b"folder_id", "labels", b"labels", "maintenance_window", b"maintenance_window", "name", b"name", "network_id", b"network_id", "security_group_ids", b"security_group_ids", "service_account_id", b"service_account_id"]) -> None: ...

global___CreateClusterRequest = CreateClusterRequest

@typing.final
class CreateClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster that is being created."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___CreateClusterMetadata = CreateClusterMetadata

@typing.final
class UpdateClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CONFIG_SPEC_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster resource to update.
    To get the OpenSearch cluster ID, use a [ClusterService.List] request.
    """
    description: builtins.str
    """New description of the OpenSearch cluster."""
    name: builtins.str
    """New name for the cluster. The name must be unique within the folder."""
    service_account_id: builtins.str
    """ID of the service account used to access Object Storage."""
    deletion_protection: builtins.bool
    """Determines whether the cluster is protected from being deleted."""
    network_id: builtins.str
    """ID of the network to move the cluster to."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the OpenSearch cluster resource should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the OpenSearch cluster as `key:value` pairs.
        For example, `"project": "mvp"` or `"source": "dictionary"`.

        The new set of labels completely replaces the old one. To add a label, request the current
        set with the [ClusterService.Get] method, then send an [ClusterService.Update] request with the new label added to the set.
        """

    @property
    def config_spec(self) -> global___ConfigUpdateSpec:
        """New cluster configuration"""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups"""

    @property
    def maintenance_window(self) -> yandex.cloud.mdb.opensearch.v1.maintenance_pb2.MaintenanceWindow:
        """Cluster maintenance window. Should be defined by either one of the two options."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        config_spec: global___ConfigUpdateSpec | None = ...,
        name: builtins.str = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        service_account_id: builtins.str = ...,
        deletion_protection: builtins.bool = ...,
        maintenance_window: yandex.cloud.mdb.opensearch.v1.maintenance_pb2.MaintenanceWindow | None = ...,
        network_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config_spec", b"config_spec", "maintenance_window", b"maintenance_window", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "config_spec", b"config_spec", "deletion_protection", b"deletion_protection", "description", b"description", "labels", b"labels", "maintenance_window", b"maintenance_window", "name", b"name", "network_id", b"network_id", "security_group_ids", b"security_group_ids", "service_account_id", b"service_account_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateClusterRequest = UpdateClusterRequest

@typing.final
class UpdateClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster resource that is being updated."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___UpdateClusterMetadata = UpdateClusterMetadata

@typing.final
class DeleteClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster to delete.
    To get the OpenSearch cluster ID, use a [ClusterService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___DeleteClusterRequest = DeleteClusterRequest

@typing.final
class DeleteClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster that is being deleted."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___DeleteClusterMetadata = DeleteClusterMetadata

@typing.final
class ListClusterLogsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ServiceType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ServiceTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ListClusterLogsRequest._ServiceType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SERVICE_TYPE_UNSPECIFIED: ListClusterLogsRequest._ServiceType.ValueType  # 0
        """Type is not specified."""
        OPENSEARCH: ListClusterLogsRequest._ServiceType.ValueType  # 1
        """OpenSearch logs."""
        DASHBOARDS: ListClusterLogsRequest._ServiceType.ValueType  # 2
        """Dashboards logs."""

    class ServiceType(_ServiceType, metaclass=_ServiceTypeEnumTypeWrapper): ...
    SERVICE_TYPE_UNSPECIFIED: ListClusterLogsRequest.ServiceType.ValueType  # 0
    """Type is not specified."""
    OPENSEARCH: ListClusterLogsRequest.ServiceType.ValueType  # 1
    """OpenSearch logs."""
    DASHBOARDS: ListClusterLogsRequest.ServiceType.ValueType  # 2
    """Dashboards logs."""

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    COLUMN_FILTER_FIELD_NUMBER: builtins.int
    FROM_TIME_FIELD_NUMBER: builtins.int
    TO_TIME_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ALWAYS_NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    SERVICE_TYPE_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster to request logs for.

    To get the OpenSearch cluster ID use a [ClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return.

    If the number of available results is larger than [page_size], the service returns a [ListClusterLogsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListClusterLogsResponse.next_page_token] returned by the previous list request.
    """
    always_next_page_token: builtins.bool
    """The service always returns a [ListClusterLogsResponse.next_page_token], even if the current page is empty."""
    filter: builtins.str
    """A filter expression that filters resources listed in the response.

    The expression must specify:

    1. A field name. Currently filtering can be applied to the [LogRecord.logs.message.hostname] field.

    2. A conditional operator. Can be either `=` or `!=` for single values, `IN` or `NOT IN` for lists of values.

    3. A value. Must be 1-63 characters long and match the regular expression `^[a-z0-9.-]{1,61}$`.

    Examples of a filter:
    * `message.hostname='node1.db.cloud.yandex.net'`;
    * `message.error_severity IN ("ERROR", "FATAL", "PANIC") AND message.hostname = "node1.db.cloud.yandex.net"`.
    """
    service_type: global___ListClusterLogsRequest.ServiceType.ValueType
    """Type of the service to request logs about."""
    @property
    def column_filter(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Columns from log table to request.
        If no columns are specified, entire log records are returned.
        """

    @property
    def from_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Start timestamp for the logs request."""

    @property
    def to_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """End timestamp for the logs request."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        column_filter: collections.abc.Iterable[builtins.str] | None = ...,
        from_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        to_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        always_next_page_token: builtins.bool = ...,
        filter: builtins.str = ...,
        service_type: global___ListClusterLogsRequest.ServiceType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["from_time", b"from_time", "to_time", b"to_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["always_next_page_token", b"always_next_page_token", "cluster_id", b"cluster_id", "column_filter", b"column_filter", "filter", b"filter", "from_time", b"from_time", "page_size", b"page_size", "page_token", b"page_token", "service_type", b"service_type", "to_time", b"to_time"]) -> None: ...

global___ListClusterLogsRequest = ListClusterLogsRequest

@typing.final
class LogRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class MessageEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    TIMESTAMP_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the log was recorded."""

    @property
    def message(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Contents of the log record."""

    def __init__(
        self,
        *,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        message: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["message", b"message", "timestamp", b"timestamp"]) -> None: ...

global___LogRecord = LogRecord

@typing.final
class ListClusterLogsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOGS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests.

    If the number of results is larger than [ListClusterLogsRequest.page_size], use the [next_page_token] as the value
    for the [ListClusterLogsRequest.page_token] query parameter in the next list request.

    Each subsequent list request has its own [next_page_token] to continue paging through the results.

    This value is interchangeable with the [StreamLogRecord.next_record_token] from [StreamLogs] method.
    """
    @property
    def logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LogRecord]:
        """Requested log records."""

    def __init__(
        self,
        *,
        logs: collections.abc.Iterable[global___LogRecord] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["logs", b"logs", "next_page_token", b"next_page_token"]) -> None: ...

global___ListClusterLogsResponse = ListClusterLogsResponse

@typing.final
class StreamLogRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECORD_FIELD_NUMBER: builtins.int
    NEXT_RECORD_TOKEN_FIELD_NUMBER: builtins.int
    next_record_token: builtins.str
    """This token allows you to continue streaming logs starting from the exact same record.

    To do that, specify value of [next_record_token] as the value for [StreamLogs.record_token] parameter in the next [StreamLogs] request.

    This value is interchangeable with [ListLogs.next_page_token] from [ListLogs] method.
    """
    @property
    def record(self) -> global___LogRecord:
        """One of the requested log records."""

    def __init__(
        self,
        *,
        record: global___LogRecord | None = ...,
        next_record_token: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["record", b"record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["next_record_token", b"next_record_token", "record", b"record"]) -> None: ...

global___StreamLogRecord = StreamLogRecord

@typing.final
class StreamClusterLogsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ServiceType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ServiceTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[StreamClusterLogsRequest._ServiceType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SERVICE_TYPE_UNSPECIFIED: StreamClusterLogsRequest._ServiceType.ValueType  # 0
        """Type is not specified."""
        OPENSEARCH: StreamClusterLogsRequest._ServiceType.ValueType  # 1
        """OpenSearch logs."""
        DASHBOARDS: StreamClusterLogsRequest._ServiceType.ValueType  # 2
        """Dashboards logs."""

    class ServiceType(_ServiceType, metaclass=_ServiceTypeEnumTypeWrapper): ...
    SERVICE_TYPE_UNSPECIFIED: StreamClusterLogsRequest.ServiceType.ValueType  # 0
    """Type is not specified."""
    OPENSEARCH: StreamClusterLogsRequest.ServiceType.ValueType  # 1
    """OpenSearch logs."""
    DASHBOARDS: StreamClusterLogsRequest.ServiceType.ValueType  # 2
    """Dashboards logs."""

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    COLUMN_FILTER_FIELD_NUMBER: builtins.int
    FROM_TIME_FIELD_NUMBER: builtins.int
    TO_TIME_FIELD_NUMBER: builtins.int
    RECORD_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    SERVICE_TYPE_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster."""
    record_token: builtins.str
    """Record token. Set `record_token` to the `next_record_token` returned by the previous [StreamLogs]
    request to start streaming from the next log record.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.

    The expression must specify:

    1. A field name. Currently filtering can be applied to the [LogRecord.logs.message.hostname] field.

    2. A conditional operator. Can be either `=` or `!=` for single values, `IN` or `NOT IN` for lists of values.

    3. A value. Must be 1-63 characters long and match the regular expression `^[a-z0-9.-]{1,61}$`.

    Examples of a filter:
    * `message.hostname='node1.db.cloud.yandex.net'`;
    * `message.error_severity IN ("ERROR", "FATAL", "PANIC") AND message.hostname = "node1.db.cloud.yandex.net"`.
    """
    service_type: global___StreamClusterLogsRequest.ServiceType.ValueType
    """Type of the service to request logs about."""
    @property
    def column_filter(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Columns from log table to get in the response.
        If no columns are specified, entire log records are returned.
        """

    @property
    def from_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Start timestamp for the logs request."""

    @property
    def to_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """End timestamp for the logs request.

        If this field is not set, all existing logs are sent as well as the new ones as they appear.

        In essence it has `tail -f` semantics.
        """

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        column_filter: collections.abc.Iterable[builtins.str] | None = ...,
        from_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        to_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        record_token: builtins.str = ...,
        filter: builtins.str = ...,
        service_type: global___StreamClusterLogsRequest.ServiceType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["from_time", b"from_time", "to_time", b"to_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "column_filter", b"column_filter", "filter", b"filter", "from_time", b"from_time", "record_token", b"record_token", "service_type", b"service_type", "to_time", b"to_time"]) -> None: ...

global___StreamClusterLogsRequest = StreamClusterLogsRequest

@typing.final
class ListClusterOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster resource to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return.

    If the number of available results is larger than [page_size], the service returns
    a [ListClusterOperationsResponse.next_page_token] that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the [ListClusterOperationsResponse.next_page_token] returned by the previous list request."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClusterOperationsRequest = ListClusterOperationsRequest

@typing.final
class ListClusterOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests.

    If the number of results is larger than [ListClusterOperationsRequest.page_size], use the [next_page_token] as the value for the [ListClusterOperationsRequest.page_token] query parameter in the next list request.

    Each subsequent list request has its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of Operation resources for the specified OpenSearch cluster."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListClusterOperationsResponse = ListClusterOperationsResponse

@typing.final
class ListClusterHostsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster.
    To get the OpenSearch cluster ID use a [ClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return.

    If the number of available results is larger than [page_size], the service returns
    a [ListClusterHostsResponse.next_page_token] that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the [ListClusterHostsResponse.next_page_token]
    returned by the previous list request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClusterHostsRequest = ListClusterHostsRequest

@typing.final
class ListClusterHostsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOSTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests.

    If the number of results is larger than [ListClusterHostsRequest.page_size], use the [next_page_token]
    as the value for the [ListClusterHostsRequest.page_token] query parameter in the next list request.

    Each subsequent list request has its own [next_page_token] to continue paging through the results.
    """
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.opensearch.v1.cluster_pb2.Host]:
        """Requested list of hosts for the cluster."""

    def __init__(
        self,
        *,
        hosts: collections.abc.Iterable[yandex.cloud.mdb.opensearch.v1.cluster_pb2.Host] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["hosts", b"hosts", "next_page_token", b"next_page_token"]) -> None: ...

global___ListClusterHostsResponse = ListClusterHostsResponse

@typing.final
class MoveClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DESTINATION_FOLDER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster to move."""
    destination_folder_id: builtins.str
    """ID of the destination folder."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        destination_folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "destination_folder_id", b"destination_folder_id"]) -> None: ...

global___MoveClusterRequest = MoveClusterRequest

@typing.final
class MoveClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    SOURCE_FOLDER_ID_FIELD_NUMBER: builtins.int
    DESTINATION_FOLDER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster being moved."""
    source_folder_id: builtins.str
    """ID of the source folder."""
    destination_folder_id: builtins.str
    """ID of the destnation folder."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        source_folder_id: builtins.str = ...,
        destination_folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "destination_folder_id", b"destination_folder_id", "source_folder_id", b"source_folder_id"]) -> None: ...

global___MoveClusterMetadata = MoveClusterMetadata

@typing.final
class StartClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster to start.
    To get the cluster ID, use a [ClusterService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StartClusterRequest = StartClusterRequest

@typing.final
class StartClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster being started."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StartClusterMetadata = StartClusterMetadata

@typing.final
class StopClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster to stop.
    To get the cluster ID, use a [ClusterService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StopClusterRequest = StopClusterRequest

@typing.final
class StopClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster being stopped."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StopClusterMetadata = StopClusterMetadata

@typing.final
class ConfigCreateSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    ADMIN_PASSWORD_FIELD_NUMBER: builtins.int
    OPENSEARCH_SPEC_FIELD_NUMBER: builtins.int
    DASHBOARDS_SPEC_FIELD_NUMBER: builtins.int
    ACCESS_FIELD_NUMBER: builtins.int
    version: builtins.str
    """OpenSearch version.
    No formal validation, a list of supported versions should suffice.
    """
    admin_password: builtins.str
    """OpenSearch admin password."""
    @property
    def opensearch_spec(self) -> global___OpenSearchCreateSpec:
        """OpenSearch configuration."""

    @property
    def dashboards_spec(self) -> global___DashboardsCreateSpec:
        """Dashboards configuration."""

    @property
    def access(self) -> yandex.cloud.mdb.opensearch.v1.cluster_pb2.Access:
        """Access policy for external services."""

    def __init__(
        self,
        *,
        version: builtins.str = ...,
        admin_password: builtins.str = ...,
        opensearch_spec: global___OpenSearchCreateSpec | None = ...,
        dashboards_spec: global___DashboardsCreateSpec | None = ...,
        access: yandex.cloud.mdb.opensearch.v1.cluster_pb2.Access | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access", b"access", "dashboards_spec", b"dashboards_spec", "opensearch_spec", b"opensearch_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access", b"access", "admin_password", b"admin_password", "dashboards_spec", b"dashboards_spec", "opensearch_spec", b"opensearch_spec", "version", b"version"]) -> None: ...

global___ConfigCreateSpec = ConfigCreateSpec

@typing.final
class KeystoreSetting(google.protobuf.message.Message):
    """Single keystore entry."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Keystore entry name."""
    value: builtins.str
    """Keystore entry value."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "value", b"value"]) -> None: ...

global___KeystoreSetting = KeystoreSetting

@typing.final
class OpenSearchCreateSpec(google.protobuf.message.Message):
    """OpenSearch create-time configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class NodeGroup(google.protobuf.message.Message):
        """Configuration of the host group."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        RESOURCES_FIELD_NUMBER: builtins.int
        HOSTS_COUNT_FIELD_NUMBER: builtins.int
        ZONE_IDS_FIELD_NUMBER: builtins.int
        SUBNET_IDS_FIELD_NUMBER: builtins.int
        ASSIGN_PUBLIC_IP_FIELD_NUMBER: builtins.int
        ROLES_FIELD_NUMBER: builtins.int
        DISK_SIZE_AUTOSCALING_FIELD_NUMBER: builtins.int
        name: builtins.str
        """Name of the group."""
        hosts_count: builtins.int
        """Number of hosts in the group."""
        assign_public_ip: builtins.bool
        """Determines whether a public IP is assigned to the hosts in the group."""
        @property
        def resources(self) -> yandex.cloud.mdb.opensearch.v1.cluster_pb2.Resources:
            """Resources allocated to the hosts."""

        @property
        def zone_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """IDs of the availability zones the hosts belong to."""

        @property
        def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """IDs of the subnets that the hosts belong to."""

        @property
        def roles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[yandex.cloud.mdb.opensearch.v1.cluster_pb2.OpenSearch.GroupRole.ValueType]:
            """Roles of the hosts in the group."""

        @property
        def disk_size_autoscaling(self) -> yandex.cloud.mdb.opensearch.v1.cluster_pb2.DiskSizeAutoscaling:
            """Disk size autoscaling settings"""

        def __init__(
            self,
            *,
            name: builtins.str = ...,
            resources: yandex.cloud.mdb.opensearch.v1.cluster_pb2.Resources | None = ...,
            hosts_count: builtins.int = ...,
            zone_ids: collections.abc.Iterable[builtins.str] | None = ...,
            subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
            assign_public_ip: builtins.bool = ...,
            roles: collections.abc.Iterable[yandex.cloud.mdb.opensearch.v1.cluster_pb2.OpenSearch.GroupRole.ValueType] | None = ...,
            disk_size_autoscaling: yandex.cloud.mdb.opensearch.v1.cluster_pb2.DiskSizeAutoscaling | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["disk_size_autoscaling", b"disk_size_autoscaling", "resources", b"resources"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["assign_public_ip", b"assign_public_ip", "disk_size_autoscaling", b"disk_size_autoscaling", "hosts_count", b"hosts_count", "name", b"name", "resources", b"resources", "roles", b"roles", "subnet_ids", b"subnet_ids", "zone_ids", b"zone_ids"]) -> None: ...

    PLUGINS_FIELD_NUMBER: builtins.int
    NODE_GROUPS_FIELD_NUMBER: builtins.int
    OPENSEARCH_CONFIG_2_FIELD_NUMBER: builtins.int
    KEYSTORE_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def plugins(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Names of the cluster plugins."""

    @property
    def node_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OpenSearchCreateSpec.NodeGroup]:
        """OpenSearch type host groups of the cluster."""

    @property
    def opensearch_config_2(self) -> yandex.cloud.mdb.opensearch.v1.config.opensearch_pb2.OpenSearchConfig2: ...
    @property
    def keystore_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___KeystoreSetting]:
        """Initial cluster keystore settings."""

    def __init__(
        self,
        *,
        plugins: collections.abc.Iterable[builtins.str] | None = ...,
        node_groups: collections.abc.Iterable[global___OpenSearchCreateSpec.NodeGroup] | None = ...,
        opensearch_config_2: yandex.cloud.mdb.opensearch.v1.config.opensearch_pb2.OpenSearchConfig2 | None = ...,
        keystore_settings: collections.abc.Iterable[global___KeystoreSetting] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config", "opensearch_config_2", b"opensearch_config_2"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config", b"config", "keystore_settings", b"keystore_settings", "node_groups", b"node_groups", "opensearch_config_2", b"opensearch_config_2", "plugins", b"plugins"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["config", b"config"]) -> typing.Literal["opensearch_config_2"] | None: ...

global___OpenSearchCreateSpec = OpenSearchCreateSpec

@typing.final
class DashboardsCreateSpec(google.protobuf.message.Message):
    """Dashboards create-time configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class NodeGroup(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        RESOURCES_FIELD_NUMBER: builtins.int
        HOSTS_COUNT_FIELD_NUMBER: builtins.int
        ZONE_IDS_FIELD_NUMBER: builtins.int
        SUBNET_IDS_FIELD_NUMBER: builtins.int
        ASSIGN_PUBLIC_IP_FIELD_NUMBER: builtins.int
        DISK_SIZE_AUTOSCALING_FIELD_NUMBER: builtins.int
        name: builtins.str
        """Name of the group."""
        hosts_count: builtins.int
        """Number of hosts in the group."""
        assign_public_ip: builtins.bool
        """Determines whether a public IP is assigned to the hosts in the group."""
        @property
        def resources(self) -> yandex.cloud.mdb.opensearch.v1.cluster_pb2.Resources:
            """Resources allocated to the hosts."""

        @property
        def zone_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """IDs of the availability zones the hosts belong to."""

        @property
        def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """IDs of the subnets that the hosts belong to."""

        @property
        def disk_size_autoscaling(self) -> yandex.cloud.mdb.opensearch.v1.cluster_pb2.DiskSizeAutoscaling:
            """Disk size autoscaling settings"""

        def __init__(
            self,
            *,
            name: builtins.str = ...,
            resources: yandex.cloud.mdb.opensearch.v1.cluster_pb2.Resources | None = ...,
            hosts_count: builtins.int = ...,
            zone_ids: collections.abc.Iterable[builtins.str] | None = ...,
            subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
            assign_public_ip: builtins.bool = ...,
            disk_size_autoscaling: yandex.cloud.mdb.opensearch.v1.cluster_pb2.DiskSizeAutoscaling | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["disk_size_autoscaling", b"disk_size_autoscaling", "resources", b"resources"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["assign_public_ip", b"assign_public_ip", "disk_size_autoscaling", b"disk_size_autoscaling", "hosts_count", b"hosts_count", "name", b"name", "resources", b"resources", "subnet_ids", b"subnet_ids", "zone_ids", b"zone_ids"]) -> None: ...

    NODE_GROUPS_FIELD_NUMBER: builtins.int
    @property
    def node_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DashboardsCreateSpec.NodeGroup]:
        """Dashboards type host groups of the cluster."""

    def __init__(
        self,
        *,
        node_groups: collections.abc.Iterable[global___DashboardsCreateSpec.NodeGroup] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["node_groups", b"node_groups"]) -> None: ...

global___DashboardsCreateSpec = DashboardsCreateSpec

@typing.final
class ConfigUpdateSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    ADMIN_PASSWORD_FIELD_NUMBER: builtins.int
    OPENSEARCH_SPEC_FIELD_NUMBER: builtins.int
    DASHBOARDS_SPEC_FIELD_NUMBER: builtins.int
    ACCESS_FIELD_NUMBER: builtins.int
    version: builtins.str
    """OpenSearch version.
    No formal validation, a list of supported versions should suffice.
    """
    admin_password: builtins.str
    """OpenSearch admin password."""
    @property
    def opensearch_spec(self) -> global___OpenSearchClusterUpdateSpec:
        """OpenSearch configuration."""

    @property
    def dashboards_spec(self) -> global___DashboardsClusterUpdateSpec:
        """Dashboards configuration."""

    @property
    def access(self) -> yandex.cloud.mdb.opensearch.v1.cluster_pb2.Access:
        """Access policy for external services."""

    def __init__(
        self,
        *,
        version: builtins.str = ...,
        admin_password: builtins.str = ...,
        opensearch_spec: global___OpenSearchClusterUpdateSpec | None = ...,
        dashboards_spec: global___DashboardsClusterUpdateSpec | None = ...,
        access: yandex.cloud.mdb.opensearch.v1.cluster_pb2.Access | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access", b"access", "dashboards_spec", b"dashboards_spec", "opensearch_spec", b"opensearch_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access", b"access", "admin_password", b"admin_password", "dashboards_spec", b"dashboards_spec", "opensearch_spec", b"opensearch_spec", "version", b"version"]) -> None: ...

global___ConfigUpdateSpec = ConfigUpdateSpec

@typing.final
class OpenSearchClusterUpdateSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLUGINS_FIELD_NUMBER: builtins.int
    OPENSEARCH_CONFIG_2_FIELD_NUMBER: builtins.int
    SET_KEYSTORE_SETTINGS_FIELD_NUMBER: builtins.int
    REMOVE_KEYSTORE_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def plugins(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Names of the cluster plugins."""

    @property
    def opensearch_config_2(self) -> yandex.cloud.mdb.opensearch.v1.config.opensearch_pb2.OpenSearchConfig2: ...
    @property
    def set_keystore_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___KeystoreSetting]:
        """Keystore settings to add/replace. Old entries not listed here will be left unchanged."""

    @property
    def remove_keystore_settings(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Keystore entries names to remove."""

    def __init__(
        self,
        *,
        plugins: collections.abc.Iterable[builtins.str] | None = ...,
        opensearch_config_2: yandex.cloud.mdb.opensearch.v1.config.opensearch_pb2.OpenSearchConfig2 | None = ...,
        set_keystore_settings: collections.abc.Iterable[global___KeystoreSetting] | None = ...,
        remove_keystore_settings: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config", "opensearch_config_2", b"opensearch_config_2"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config", b"config", "opensearch_config_2", b"opensearch_config_2", "plugins", b"plugins", "remove_keystore_settings", b"remove_keystore_settings", "set_keystore_settings", b"set_keystore_settings"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["config", b"config"]) -> typing.Literal["opensearch_config_2"] | None: ...

global___OpenSearchClusterUpdateSpec = OpenSearchClusterUpdateSpec

@typing.final
class DashboardsClusterUpdateSpec(google.protobuf.message.Message):
    """Dashboards configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DashboardsClusterUpdateSpec = DashboardsClusterUpdateSpec

@typing.final
class BackupClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster to back up.

    To get the ID, use a [ClusterService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___BackupClusterRequest = BackupClusterRequest

@typing.final
class BackupClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster being backed up."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___BackupClusterMetadata = BackupClusterMetadata

@typing.final
class RestoreClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    BACKUP_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    CONFIG_SPEC_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    backup_id: builtins.str
    """ID of the backup to create a new cluster from.

    To get the backup ID, use a [ClusterService.ListBackups] request.
    """
    name: builtins.str
    """Name of the new OpenSearch cluster to be created from the backup. The name must be unique within the folder."""
    description: builtins.str
    """Description of the new OpenSearch cluster to be created from the backup."""
    environment: yandex.cloud.mdb.opensearch.v1.cluster_pb2.Cluster.Environment.ValueType
    """Deployment environment of the new OpenSearch cluster to be created from the backup."""
    network_id: builtins.str
    """ID of the network to create the cluster in."""
    service_account_id: builtins.str
    """ID of the service account used to access Object Storage."""
    deletion_protection: builtins.bool
    """Determines whether the cluster is protected from being deleted."""
    folder_id: builtins.str
    """ID of the folder to create the OpenSearch cluster in.

    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the new OpenSearch cluster to be created from the backup as `key:value` pairs. Maximum 64 per resource.
        For example, "project": "mvp" or "source": "dictionary".
        """

    @property
    def config_spec(self) -> global___ConfigCreateSpec:
        """Configuration for the new OpenSearch cluster to be created from the backup."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups."""

    @property
    def maintenance_window(self) -> yandex.cloud.mdb.opensearch.v1.maintenance_pb2.MaintenanceWindow:
        """Cluster maintenance window. Should be defined by either one of the two options."""

    def __init__(
        self,
        *,
        backup_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        environment: yandex.cloud.mdb.opensearch.v1.cluster_pb2.Cluster.Environment.ValueType = ...,
        config_spec: global___ConfigCreateSpec | None = ...,
        network_id: builtins.str = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        service_account_id: builtins.str = ...,
        deletion_protection: builtins.bool = ...,
        folder_id: builtins.str = ...,
        maintenance_window: yandex.cloud.mdb.opensearch.v1.maintenance_pb2.MaintenanceWindow | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config_spec", b"config_spec", "maintenance_window", b"maintenance_window"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id", "config_spec", b"config_spec", "deletion_protection", b"deletion_protection", "description", b"description", "environment", b"environment", "folder_id", b"folder_id", "labels", b"labels", "maintenance_window", b"maintenance_window", "name", b"name", "network_id", b"network_id", "security_group_ids", b"security_group_ids", "service_account_id", b"service_account_id"]) -> None: ...

global___RestoreClusterRequest = RestoreClusterRequest

@typing.final
class RestoreClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    BACKUP_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the new OpenSearch cluster being created from a backup."""
    backup_id: builtins.str
    """ID of the backup being used for creating a cluster."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        backup_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id", "cluster_id", b"cluster_id"]) -> None: ...

global___RestoreClusterMetadata = RestoreClusterMetadata

@typing.final
class RescheduleMaintenanceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _RescheduleType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RescheduleTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RescheduleMaintenanceRequest._RescheduleType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        RESCHEDULE_TYPE_UNSPECIFIED: RescheduleMaintenanceRequest._RescheduleType.ValueType  # 0
        """Time of the maintenance is not specified.."""
        IMMEDIATE: RescheduleMaintenanceRequest._RescheduleType.ValueType  # 1
        """Start the maintenance operation immediately."""
        NEXT_AVAILABLE_WINDOW: RescheduleMaintenanceRequest._RescheduleType.ValueType  # 2
        """Start the maintenance operation within the next available maintenance window."""
        SPECIFIC_TIME: RescheduleMaintenanceRequest._RescheduleType.ValueType  # 3
        """Start the maintenance operation at the specific time."""

    class RescheduleType(_RescheduleType, metaclass=_RescheduleTypeEnumTypeWrapper): ...
    RESCHEDULE_TYPE_UNSPECIFIED: RescheduleMaintenanceRequest.RescheduleType.ValueType  # 0
    """Time of the maintenance is not specified.."""
    IMMEDIATE: RescheduleMaintenanceRequest.RescheduleType.ValueType  # 1
    """Start the maintenance operation immediately."""
    NEXT_AVAILABLE_WINDOW: RescheduleMaintenanceRequest.RescheduleType.ValueType  # 2
    """Start the maintenance operation within the next available maintenance window."""
    SPECIFIC_TIME: RescheduleMaintenanceRequest.RescheduleType.ValueType  # 3
    """Start the maintenance operation at the specific time."""

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    RESCHEDULE_TYPE_FIELD_NUMBER: builtins.int
    DELAYED_UNTIL_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster to reschedule the maintenance operation for.

    To get the ID, use a [ClusterService.List] request.
    """
    reschedule_type: global___RescheduleMaintenanceRequest.RescheduleType.ValueType
    """The type of the reschedule request."""
    @property
    def delayed_until(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time until which this maintenance operation should be delayed.
        The value should be ahead of the first time when the maintenance operation has been scheduled for no more than two weeks.
        The value can also point to a moment in the past if [reschedule_type.IMMEDIATE] reschedule type is selected.
        """

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        reschedule_type: global___RescheduleMaintenanceRequest.RescheduleType.ValueType = ...,
        delayed_until: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["delayed_until", b"delayed_until"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "delayed_until", b"delayed_until", "reschedule_type", b"reschedule_type"]) -> None: ...

global___RescheduleMaintenanceRequest = RescheduleMaintenanceRequest

@typing.final
class RescheduleMaintenanceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DELAYED_UNTIL_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster where the reschedule is applied."""
    @property
    def delayed_until(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time until which this maintenance operation is to be delayed."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        delayed_until: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["delayed_until", b"delayed_until"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "delayed_until", b"delayed_until"]) -> None: ...

global___RescheduleMaintenanceMetadata = RescheduleMaintenanceMetadata

@typing.final
class ListClusterBackupsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster.

    To get the ID, use a [ClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListClusterBackupsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the [ListClusterBackupsResponse.next_page_token]
    returned by the previous list request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClusterBackupsRequest = ListClusterBackupsRequest

@typing.final
class ListClusterBackupsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKUPS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests.

    If the number of results is larger than [ListClustersRequest.page_size], use the [next_page_token] as the value
    for the [ListClustersRequest.page_token] parameter in the next list request.

    Each subsequent list request has its own [next_page_token] to continue paging through the results.
    """
    @property
    def backups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.opensearch.v1.backup_pb2.Backup]:
        """List of the OpenSearch cluster backups."""

    def __init__(
        self,
        *,
        backups: collections.abc.Iterable[yandex.cloud.mdb.opensearch.v1.backup_pb2.Backup] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backups", b"backups", "next_page_token", b"next_page_token"]) -> None: ...

global___ListClusterBackupsResponse = ListClusterBackupsResponse

@typing.final
class DeleteOpenSearchNodeGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster to delete the OpenSearch type host group in.

    To get the ID, use a [ClusterService.List] request.
    """
    name: builtins.str
    """Name of the OpenSearch type host group to delete."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "name", b"name"]) -> None: ...

global___DeleteOpenSearchNodeGroupRequest = DeleteOpenSearchNodeGroupRequest

@typing.final
class UpdateOpenSearchNodeGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NODE_GROUP_SPEC_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster to update the OpenSearch type host group in.

    To get the ID, use a [ClusterService.List] request.
    """
    name: builtins.str
    """Name of the OpenSearch type host group to be updated."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the host group configuration should be updated."""

    @property
    def node_group_spec(self) -> global___OpenSearchNodeGroupUpdateSpec:
        """New configuration for the host group."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        name: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        node_group_spec: global___OpenSearchNodeGroupUpdateSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_group_spec", b"node_group_spec", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "name", b"name", "node_group_spec", b"node_group_spec", "update_mask", b"update_mask"]) -> None: ...

global___UpdateOpenSearchNodeGroupRequest = UpdateOpenSearchNodeGroupRequest

@typing.final
class OpenSearchNodeGroupUpdateSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCES_FIELD_NUMBER: builtins.int
    HOSTS_COUNT_FIELD_NUMBER: builtins.int
    ROLES_FIELD_NUMBER: builtins.int
    ZONE_IDS_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    ASSIGN_PUBLIC_IP_FIELD_NUMBER: builtins.int
    DISK_SIZE_AUTOSCALING_FIELD_NUMBER: builtins.int
    hosts_count: builtins.int
    """Number of hosts in the group."""
    assign_public_ip: builtins.bool
    """Whether the hosts should get a public IP address."""
    @property
    def resources(self) -> yandex.cloud.mdb.opensearch.v1.cluster_pb2.Resources:
        """Resources allocated to the hosts."""

    @property
    def roles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[yandex.cloud.mdb.opensearch.v1.cluster_pb2.OpenSearch.GroupRole.ValueType]:
        """Opensearch roles applicable to the node group."""

    @property
    def zone_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of the availability zones for hosts"""

    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of the subnets for hosts"""

    @property
    def disk_size_autoscaling(self) -> yandex.cloud.mdb.opensearch.v1.cluster_pb2.DiskSizeAutoscaling:
        """Disk size autoscaling settings"""

    def __init__(
        self,
        *,
        resources: yandex.cloud.mdb.opensearch.v1.cluster_pb2.Resources | None = ...,
        hosts_count: builtins.int = ...,
        roles: collections.abc.Iterable[yandex.cloud.mdb.opensearch.v1.cluster_pb2.OpenSearch.GroupRole.ValueType] | None = ...,
        zone_ids: collections.abc.Iterable[builtins.str] | None = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        assign_public_ip: builtins.bool = ...,
        disk_size_autoscaling: yandex.cloud.mdb.opensearch.v1.cluster_pb2.DiskSizeAutoscaling | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["disk_size_autoscaling", b"disk_size_autoscaling", "resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["assign_public_ip", b"assign_public_ip", "disk_size_autoscaling", b"disk_size_autoscaling", "hosts_count", b"hosts_count", "resources", b"resources", "roles", b"roles", "subnet_ids", b"subnet_ids", "zone_ids", b"zone_ids"]) -> None: ...

global___OpenSearchNodeGroupUpdateSpec = OpenSearchNodeGroupUpdateSpec

@typing.final
class AddOpenSearchNodeGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    NODE_GROUP_SPEC_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster to create the OpenSearch type host group in.

    To get the ID, use a [ClusterService.List] request.
    """
    @property
    def node_group_spec(self) -> global___OpenSearchCreateSpec.NodeGroup:
        """Configuration of the new host group."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        node_group_spec: global___OpenSearchCreateSpec.NodeGroup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_group_spec", b"node_group_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "node_group_spec", b"node_group_spec"]) -> None: ...

global___AddOpenSearchNodeGroupRequest = AddOpenSearchNodeGroupRequest

@typing.final
class DeleteDashboardsNodeGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster to delete the Dashboards type host group in.

    To get the ID, use a [ClusterService.List] request.
    """
    name: builtins.str
    """Name of the Dashboards type host group to delete."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "name", b"name"]) -> None: ...

global___DeleteDashboardsNodeGroupRequest = DeleteDashboardsNodeGroupRequest

@typing.final
class UpdateDashboardsNodeGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NODE_GROUP_SPEC_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster to update the Dashboards type host group in."""
    name: builtins.str
    """Name of the Dashboards type host group to be updated."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the host group configuration should be updated."""

    @property
    def node_group_spec(self) -> global___DashboardsNodeGroupUpdateSpec:
        """New configuration for the host group."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        name: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        node_group_spec: global___DashboardsNodeGroupUpdateSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_group_spec", b"node_group_spec", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "name", b"name", "node_group_spec", b"node_group_spec", "update_mask", b"update_mask"]) -> None: ...

global___UpdateDashboardsNodeGroupRequest = UpdateDashboardsNodeGroupRequest

@typing.final
class DashboardsNodeGroupUpdateSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCES_FIELD_NUMBER: builtins.int
    HOSTS_COUNT_FIELD_NUMBER: builtins.int
    ZONE_IDS_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    ASSIGN_PUBLIC_IP_FIELD_NUMBER: builtins.int
    DISK_SIZE_AUTOSCALING_FIELD_NUMBER: builtins.int
    hosts_count: builtins.int
    """Number of hosts in the group."""
    assign_public_ip: builtins.bool
    """Whether the hosts should get a public IP address."""
    @property
    def resources(self) -> yandex.cloud.mdb.opensearch.v1.cluster_pb2.Resources:
        """Resources allocated to the hosts."""

    @property
    def zone_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of the availability zones for hosts"""

    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of the subnets for hosts"""

    @property
    def disk_size_autoscaling(self) -> yandex.cloud.mdb.opensearch.v1.cluster_pb2.DiskSizeAutoscaling:
        """Disk size autoscaling settings"""

    def __init__(
        self,
        *,
        resources: yandex.cloud.mdb.opensearch.v1.cluster_pb2.Resources | None = ...,
        hosts_count: builtins.int = ...,
        zone_ids: collections.abc.Iterable[builtins.str] | None = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        assign_public_ip: builtins.bool = ...,
        disk_size_autoscaling: yandex.cloud.mdb.opensearch.v1.cluster_pb2.DiskSizeAutoscaling | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["disk_size_autoscaling", b"disk_size_autoscaling", "resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["assign_public_ip", b"assign_public_ip", "disk_size_autoscaling", b"disk_size_autoscaling", "hosts_count", b"hosts_count", "resources", b"resources", "subnet_ids", b"subnet_ids", "zone_ids", b"zone_ids"]) -> None: ...

global___DashboardsNodeGroupUpdateSpec = DashboardsNodeGroupUpdateSpec

@typing.final
class AddDashboardsNodeGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    NODE_GROUP_SPEC_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster to create the Dashboards type host group in.

    To get the ID, use a [ClusterService.List] request.
    """
    @property
    def node_group_spec(self) -> global___DashboardsCreateSpec.NodeGroup:
        """Configuration of the new host group."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        node_group_spec: global___DashboardsCreateSpec.NodeGroup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["node_group_spec", b"node_group_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "node_group_spec", b"node_group_spec"]) -> None: ...

global___AddDashboardsNodeGroupRequest = AddDashboardsNodeGroupRequest

@typing.final
class AddNodeGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster where the host group is being created."""
    name: builtins.str
    """Name of the host group being created."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "name", b"name"]) -> None: ...

global___AddNodeGroupMetadata = AddNodeGroupMetadata

@typing.final
class UpdateNodeGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster where the host group is being updated."""
    name: builtins.str
    """Name of the host group being updated."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "name", b"name"]) -> None: ...

global___UpdateNodeGroupMetadata = UpdateNodeGroupMetadata

@typing.final
class DeleteNodeGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster where the host group is being deleted."""
    name: builtins.str
    """Name of the host group being deleted."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "name", b"name"]) -> None: ...

global___DeleteNodeGroupMetadata = DeleteNodeGroupMetadata

@typing.final
class GetAuthSettingsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Required. ID of the OpenSearch cluster."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___GetAuthSettingsRequest = GetAuthSettingsRequest

@typing.final
class UpdateAuthSettingsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Required. ID of the OpenSearch cluster."""
    @property
    def settings(self) -> yandex.cloud.mdb.opensearch.v1.auth_pb2.AuthSettings:
        """Required. Auth settings."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        settings: yandex.cloud.mdb.opensearch.v1.auth_pb2.AuthSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "settings", b"settings"]) -> None: ...

global___UpdateAuthSettingsRequest = UpdateAuthSettingsRequest

@typing.final
class UpdateAuthSettingsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the OpenSearch cluster."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___UpdateAuthSettingsMetadata = UpdateAuthSettingsMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.serverless.mdbproxy.v1.proxy_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetProxyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROXY_ID_FIELD_NUMBER: builtins.int
    proxy_id: builtins.str
    """ID of the proxy to return.

    To get a proxy ID make a [ProxyService.List] request.
    """
    def __init__(
        self,
        *,
        proxy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["proxy_id", b"proxy_id"]) -> None: ...

global___GetProxyRequest = GetProxyRequest

@typing.final
class ListProxyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list proxies in.

    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `pageSize`, the service returns a [ListProxyResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `pageToken` to the
    [ListProxyResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters proxies listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can only be applied to the [Proxy.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name=my-proxy`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListProxyRequest = ListProxyRequest

@typing.final
class ListProxyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROXIES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListProxyRequest.page_size], use `nextPageToken` as the value
    for the [ListProxyRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `nextPageToken` to continue paging through the results.
    """
    @property
    def proxies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.mdbproxy.v1.proxy_pb2.Proxy]:
        """List of proxies in the specified folder."""

    def __init__(
        self,
        *,
        proxies: collections.abc.Iterable[yandex.cloud.serverless.mdbproxy.v1.proxy_pb2.Proxy] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "proxies", b"proxies"]) -> None: ...

global___ListProxyResponse = ListProxyResponse

@typing.final
class CreateProxyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a proxy in.

    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the proxy.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the proxy."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def target(self) -> yandex.cloud.serverless.mdbproxy.v1.proxy_pb2.Target:
        """Proxy target."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        target: yandex.cloud.serverless.mdbproxy.v1.proxy_pb2.Target | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "target", b"target"]) -> None: ...

global___CreateProxyRequest = CreateProxyRequest

@typing.final
class CreateProxyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROXY_ID_FIELD_NUMBER: builtins.int
    proxy_id: builtins.str
    """ID of the proxy."""
    def __init__(
        self,
        *,
        proxy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["proxy_id", b"proxy_id"]) -> None: ...

global___CreateProxyMetadata = CreateProxyMetadata

@typing.final
class UpdateProxyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    PROXY_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    proxy_id: builtins.str
    """ID of the proxy to update."""
    name: builtins.str
    """New name for the proxy.
    The name must be unique within the folder.
    """
    description: builtins.str
    """New description for the proxy."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the proxy should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Proxy labels as `key:value` pairs."""

    @property
    def target(self) -> yandex.cloud.serverless.mdbproxy.v1.proxy_pb2.Target:
        """Proxy target."""

    def __init__(
        self,
        *,
        proxy_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        target: yandex.cloud.serverless.mdbproxy.v1.proxy_pb2.Target | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["target", b"target", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "labels", b"labels", "name", b"name", "proxy_id", b"proxy_id", "target", b"target", "update_mask", b"update_mask"]) -> None: ...

global___UpdateProxyRequest = UpdateProxyRequest

@typing.final
class UpdateProxyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROXY_ID_FIELD_NUMBER: builtins.int
    proxy_id: builtins.str
    """ID of the proxy."""
    def __init__(
        self,
        *,
        proxy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["proxy_id", b"proxy_id"]) -> None: ...

global___UpdateProxyMetadata = UpdateProxyMetadata

@typing.final
class DeleteProxyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROXY_ID_FIELD_NUMBER: builtins.int
    proxy_id: builtins.str
    """ID of the proxy."""
    def __init__(
        self,
        *,
        proxy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["proxy_id", b"proxy_id"]) -> None: ...

global___DeleteProxyRequest = DeleteProxyRequest

@typing.final
class DeleteProxyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROXY_ID_FIELD_NUMBER: builtins.int
    proxy_id: builtins.str
    """ID of the proxy."""
    def __init__(
        self,
        *,
        proxy_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["proxy_id", b"proxy_id"]) -> None: ...

global___DeleteProxyMetadata = DeleteProxyMetadata

@typing.final
class ListProxyOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROXY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    proxy_id: builtins.str
    """ID of the proxy to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `pageSize`, the service returns a [ListProxyOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `pageToken` to the
    [ListProxyOperationsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can be applied to the [operation.Operation.done], [operation.Operation.created_by] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Examples of a filter: `done=false`, `created_by='John.Doe'`.
    """
    def __init__(
        self,
        *,
        proxy_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "proxy_id", b"proxy_id"]) -> None: ...

global___ListProxyOperationsRequest = ListProxyOperationsRequest

@typing.final
class ListProxyOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListProxyOperationsRequest.page_size], use `nextPageToken` as the value
    for the [ListProxyOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `nextPageToken` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified proxy."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListProxyOperationsResponse = ListProxyOperationsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/storage/v1/bucket.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$yandex/cloud/storage/v1/bucket.proto\x12\x17yandex.cloud.storage.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xc7\x05\n\x06\x42ucket\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x03 \x01(\t\x12M\n\x16\x61nonymous_access_flags\x18\x04 \x01(\x0b\x32-.yandex.cloud.storage.v1.AnonymousAccessFlags\x12\x1d\n\x15\x64\x65\x66\x61ult_storage_class\x18\x05 \x01(\t\x12\x37\n\nversioning\x18\x06 \x01(\x0e\x32#.yandex.cloud.storage.v1.Versioning\x12\x10\n\x08max_size\x18\x07 \x01(\x03\x12\'\n\x06policy\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x03\x61\x63l\x18\t \x01(\x0b\x32\x1c.yandex.cloud.storage.v1.ACL\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x04\x63ors\x18\x0b \x03(\x0b\x32!.yandex.cloud.storage.v1.CorsRule\x12\x42\n\x10website_settings\x18\x0c \x01(\x0b\x32(.yandex.cloud.storage.v1.WebsiteSettings\x12?\n\x0flifecycle_rules\x18\r \x03(\x0b\x32&.yandex.cloud.storage.v1.LifecycleRule\x12*\n\x04tags\x18\x0e \x03(\x0b\x32\x1c.yandex.cloud.storage.v1.Tag\x12\x38\n\x0bobject_lock\x18\x0f \x01(\x0b\x32#.yandex.cloud.storage.v1.ObjectLock\x12\x37\n\nencryption\x18\x10 \x01(\x0b\x32#.yandex.cloud.storage.v1.Encryption\"!\n\x03Tag\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x92\x04\n\x03\x41\x43L\x12\x32\n\x06grants\x18\x01 \x03(\x0b\x32\".yandex.cloud.storage.v1.ACL.Grant\x1a\xd6\x03\n\x05Grant\x12G\n\npermission\x18\x01 \x01(\x0e\x32-.yandex.cloud.storage.v1.ACL.Grant.PermissionB\x04\xe8\xc7\x31\x01\x12\x46\n\ngrant_type\x18\x02 \x01(\x0e\x32,.yandex.cloud.storage.v1.ACL.Grant.GrantTypeB\x04\xe8\xc7\x31\x01\x12\x12\n\ngrantee_id\x18\x03 \x01(\t\"\xa3\x01\n\nPermission\x12\x1a\n\x16PERMISSION_UNSPECIFIED\x10\x00\x12\x1b\n\x17PERMISSION_FULL_CONTROL\x10\x01\x12\x14\n\x10PERMISSION_WRITE\x10\x02\x12\x18\n\x14PERMISSION_WRITE_ACP\x10\x03\x12\x13\n\x0fPERMISSION_READ\x10\x04\x12\x17\n\x13PERMISSION_READ_ACP\x10\x05\"\x81\x01\n\tGrantType\x12\x1a\n\x16GRANT_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12GRANT_TYPE_ACCOUNT\x10\x01\x12&\n\"GRANT_TYPE_ALL_AUTHENTICATED_USERS\x10\x02\x12\x18\n\x14GRANT_TYPE_ALL_USERS\x10\x03\"\x9b\x01\n\x14\x41nonymousAccessFlags\x12(\n\x04read\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12(\n\x04list\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12/\n\x0b\x63onfig_read\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xe4\x02\n\x08\x43orsRule\x12\n\n\x02id\x18\x01 \x01(\t\x12M\n\x0f\x61llowed_methods\x18\x02 \x03(\x0e\x32(.yandex.cloud.storage.v1.CorsRule.MethodB\n\x82\xc8\x31\x02>0\x90\xc8\x31\x01\x12\x17\n\x0f\x61llowed_headers\x18\x03 \x03(\t\x12\x1f\n\x0f\x61llowed_origins\x18\x04 \x03(\tB\x06\x82\xc8\x31\x02>0\x12\x16\n\x0e\x65xpose_headers\x18\x05 \x03(\t\x12\x34\n\x0fmax_age_seconds\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"u\n\x06Method\x12\x16\n\x12METHOD_UNSPECIFIED\x10\x00\x12\x0e\n\nMETHOD_GET\x10\x01\x12\x0f\n\x0bMETHOD_HEAD\x10\x02\x12\x0f\n\x0bMETHOD_POST\x10\x03\x12\x0e\n\nMETHOD_PUT\x10\x04\x12\x11\n\rMETHOD_DELETE\x10\x05\"\xbc\x06\n\x0fWebsiteSettings\x12\r\n\x05index\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12N\n\x15redirect_all_requests\x18\x03 \x01(\x0b\x32/.yandex.cloud.storage.v1.WebsiteSettings.Scheme\x12K\n\rrouting_rules\x18\x04 \x03(\x0b\x32\x34.yandex.cloud.storage.v1.WebsiteSettings.RoutingRule\x1a_\n\x06Scheme\x12\x43\n\x08protocol\x18\x01 \x01(\x0e\x32\x31.yandex.cloud.storage.v1.WebsiteSettings.Protocol\x12\x10\n\x08hostname\x18\x02 \x01(\t\x1aO\n\tCondition\x12\'\n\x1fhttp_error_code_returned_equals\x18\x01 \x01(\t\x12\x19\n\x11key_prefix_equals\x18\x02 \x01(\t\x1a\xd2\x01\n\x08Redirect\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12\x34\n\x12http_redirect_code\x18\x02 \x01(\tB\x18\xf2\xc7\x31\x14\x33(0[1-9]|[1-9][0-9])\x12\x43\n\x08protocol\x18\x03 \x01(\x0e\x32\x31.yandex.cloud.storage.v1.WebsiteSettings.Protocol\x12\x1f\n\x17replace_key_prefix_with\x18\x04 \x01(\t\x12\x18\n\x10replace_key_with\x18\x05 \x01(\t\x1a\x99\x01\n\x0bRoutingRule\x12\x45\n\tcondition\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.storage.v1.WebsiteSettings.Condition\x12\x43\n\x08redirect\x18\x02 \x01(\x0b\x32\x31.yandex.cloud.storage.v1.WebsiteSettings.Redirect\"K\n\x08Protocol\x12\x18\n\x14PROTOCOL_UNSPECIFIED\x10\x00\x12\x11\n\rPROTOCOL_HTTP\x10\x01\x12\x12\n\x0ePROTOCOL_HTTPS\x10\x02\"\xe5\r\n\rLifecycleRule\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x41\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x31.yandex.cloud.storage.v1.LifecycleRule.RuleFilter\x12\x45\n\nexpiration\x18\x04 \x01(\x0b\x32\x31.yandex.cloud.storage.v1.LifecycleRule.Expiration\x12\x46\n\x0btransitions\x18\x05 \x03(\x0b\x32\x31.yandex.cloud.storage.v1.LifecycleRule.Transition\x12[\n!abort_incomplete_multipart_upload\x18\x06 \x01(\x0b\x32\x30.yandex.cloud.storage.v1.LifecycleRule.AfterDays\x12Z\n\x15noncurrent_expiration\x18\x07 \x01(\x0b\x32;.yandex.cloud.storage.v1.LifecycleRule.NoncurrentExpiration\x12[\n\x16noncurrent_transitions\x18\x08 \x03(\x0b\x32;.yandex.cloud.storage.v1.LifecycleRule.NoncurrentTransition\x12\x61\n\x19noncurrent_delete_markers\x18\t \x01(\x0b\x32>.yandex.cloud.storage.v1.LifecycleRule.NoncurrentDeleteMarkers\x1aG\n\tAfterDays\x12:\n\x15\x64\x61ys_after_expiration\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1aO\n\x17NoncurrentDeleteMarkers\x12\x34\n\x0fnoncurrent_days\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1aL\n\x14NoncurrentExpiration\x12\x34\n\x0fnoncurrent_days\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1ai\n\x14NoncurrentTransition\x12\x34\n\x0fnoncurrent_days\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x1b\n\rstorage_class\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x1a\x84\x01\n\nTransition\x12(\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x04\x64\x61ys\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x1b\n\rstorage_class\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01J\x04\x08\x03\x10\x04\x1a\xa3\x01\n\nExpiration\x12(\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x04\x64\x61ys\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x1c\x65xpired_object_delete_marker\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\xcd\x03\n\nRuleFilter\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12=\n\x18object_size_greater_than\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x15object_size_less_than\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12)\n\x03tag\x18\x04 \x01(\x0b\x32\x1c.yandex.cloud.storage.v1.Tag\x12K\n\x0c\x61nd_operator\x18\x05 \x01(\x0b\x32\x35.yandex.cloud.storage.v1.LifecycleRule.RuleFilter.And\x1a\xbb\x01\n\x03\x41nd\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12=\n\x18object_size_greater_than\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x15object_size_less_than\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12)\n\x03tag\x18\x04 \x03(\x0b\x32\x1c.yandex.cloud.storage.v1.Tag\"\xdd\x01\n\x08\x43ounters\x12\x1a\n\x12simple_object_size\x18\x01 \x01(\x03\x12\x1b\n\x13simple_object_count\x18\x02 \x01(\x03\x12\x1a\n\x12objects_parts_size\x18\x03 \x01(\x03\x12\x1b\n\x13objects_parts_count\x18\x04 \x01(\x03\x12\x1e\n\x16multipart_objects_size\x18\x05 \x01(\x03\x12\x1f\n\x17multipart_objects_count\x18\x06 \x01(\x03\x12\x1e\n\x16\x61\x63tive_multipart_count\x18\x07 \x01(\x03\"]\n\x13OptionalSizeByClass\x12\x15\n\rstorage_class\x18\x01 \x01(\t\x12/\n\nclass_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"8\n\x0bSizeByClass\x12\x15\n\rstorage_class\x18\x01 \x01(\t\x12\x12\n\nclass_size\x18\x02 \x01(\x03\"]\n\x0f\x43ountersByClass\x12\x15\n\rstorage_class\x18\x01 \x01(\t\x12\x33\n\x08\x63ounters\x18\x02 \x01(\x0b\x32!.yandex.cloud.storage.v1.Counters\"\xaa\x04\n\x0b\x42ucketStats\x12\x0c\n\x04name\x18\x01 \x01(\t\x12-\n\x08max_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x11\n\tused_size\x18\x03 \x01(\x03\x12M\n\x17storage_class_max_sizes\x18\x04 \x03(\x0b\x32,.yandex.cloud.storage.v1.OptionalSizeByClass\x12\x46\n\x18storage_class_used_sizes\x18\x05 \x03(\x0b\x32$.yandex.cloud.storage.v1.SizeByClass\x12H\n\x16storage_class_counters\x18\x06 \x03(\x0b\x32(.yandex.cloud.storage.v1.CountersByClass\x12;\n\x15\x64\x65\x66\x61ult_storage_class\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12M\n\x16\x61nonymous_access_flags\x18\x08 \x01(\x0b\x32-.yandex.cloud.storage.v1.AnonymousAccessFlags\x12.\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xc1\x03\n\x0bHTTPSConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x44\n\x0bsource_type\x18\x02 \x01(\x0e\x32/.yandex.cloud.storage.v1.HTTPSConfig.SourceType\x12,\n\x06issuer\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07subject\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x11\n\tdns_names\x18\x05 \x03(\t\x12.\n\nnot_before\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tnot_after\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0e\x63\x65rtificate_id\x18\x08 \x01(\t\"w\n\nSourceType\x12\x1b\n\x17SOURCE_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18SOURCE_TYPE_SELF_MANAGED\x10\x01\x12.\n*SOURCE_TYPE_MANAGED_BY_CERTIFICATE_MANAGER\x10\x02\"\xf3\x03\n\nObjectLock\x12\x44\n\x06status\x18\x02 \x01(\x0e\x32\x34.yandex.cloud.storage.v1.ObjectLock.ObjectLockStatus\x12O\n\x11\x64\x65\x66\x61ult_retention\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.storage.v1.ObjectLock.DefaultRetention\x1a\xd4\x01\n\x10\x44\x65\x66\x61ultRetention\x12G\n\x04mode\x18\x01 \x01(\x0e\x32\x39.yandex.cloud.storage.v1.ObjectLock.DefaultRetention.Mode\x12\x0e\n\x04\x64\x61ys\x18\x02 \x01(\x03H\x00\x12\x0f\n\x05years\x18\x03 \x01(\x03H\x00\"F\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x13\n\x0fMODE_GOVERNANCE\x10\x01\x12\x13\n\x0fMODE_COMPLIANCE\x10\x02\x42\x0e\n\x06period\x12\x04\xc0\xc1\x31\x01\"w\n\x10ObjectLockStatus\x12\"\n\x1eOBJECT_LOCK_STATUS_UNSPECIFIED\x10\x00\x12\x1f\n\x1bOBJECT_LOCK_STATUS_DISABLED\x10\x01\x12\x1e\n\x1aOBJECT_LOCK_STATUS_ENABLED\x10\x02\"\x93\x01\n\nEncryption\x12\x41\n\x05rules\x18\x01 \x03(\x0b\x32\x32.yandex.cloud.storage.v1.Encryption.EncryptionRule\x1a\x42\n\x0e\x45ncryptionRule\x12\x19\n\x11kms_master_key_id\x18\x01 \x01(\t\x12\x15\n\rsse_algorithm\x18\x02 \x01(\t*s\n\nVersioning\x12\x1a\n\x16VERSIONING_UNSPECIFIED\x10\x00\x12\x17\n\x13VERSIONING_DISABLED\x10\x01\x12\x16\n\x12VERSIONING_ENABLED\x10\x02\x12\x18\n\x14VERSIONING_SUSPENDED\x10\x03\x42\x62\n\x1byandex.cloud.api.storage.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/storage/v1;storageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.storage.v1.bucket_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.storage.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/storage/v1;storage'
  _ACL_GRANT.fields_by_name['permission']._options = None
  _ACL_GRANT.fields_by_name['permission']._serialized_options = b'\350\3071\001'
  _ACL_GRANT.fields_by_name['grant_type']._options = None
  _ACL_GRANT.fields_by_name['grant_type']._serialized_options = b'\350\3071\001'
  _CORSRULE.fields_by_name['allowed_methods']._options = None
  _CORSRULE.fields_by_name['allowed_methods']._serialized_options = b'\202\3101\002>0\220\3101\001'
  _CORSRULE.fields_by_name['allowed_origins']._options = None
  _CORSRULE.fields_by_name['allowed_origins']._serialized_options = b'\202\3101\002>0'
  _WEBSITESETTINGS_REDIRECT.fields_by_name['http_redirect_code']._options = None
  _WEBSITESETTINGS_REDIRECT.fields_by_name['http_redirect_code']._serialized_options = b'\362\3071\0243(0[1-9]|[1-9][0-9])'
  _LIFECYCLERULE_NONCURRENTTRANSITION.fields_by_name['storage_class']._options = None
  _LIFECYCLERULE_NONCURRENTTRANSITION.fields_by_name['storage_class']._serialized_options = b'\350\3071\001'
  _LIFECYCLERULE_TRANSITION.fields_by_name['storage_class']._options = None
  _LIFECYCLERULE_TRANSITION.fields_by_name['storage_class']._serialized_options = b'\350\3071\001'
  _OBJECTLOCK_DEFAULTRETENTION.oneofs_by_name['period']._options = None
  _OBJECTLOCK_DEFAULTRETENTION.oneofs_by_name['period']._serialized_options = b'\300\3011\001'
  _globals['_VERSIONING']._serialized_start=6722
  _globals['_VERSIONING']._serialized_end=6837
  _globals['_BUCKET']._serialized_start=192
  _globals['_BUCKET']._serialized_end=903
  _globals['_TAG']._serialized_start=905
  _globals['_TAG']._serialized_end=938
  _globals['_ACL']._serialized_start=941
  _globals['_ACL']._serialized_end=1471
  _globals['_ACL_GRANT']._serialized_start=1001
  _globals['_ACL_GRANT']._serialized_end=1471
  _globals['_ACL_GRANT_PERMISSION']._serialized_start=1176
  _globals['_ACL_GRANT_PERMISSION']._serialized_end=1339
  _globals['_ACL_GRANT_GRANTTYPE']._serialized_start=1342
  _globals['_ACL_GRANT_GRANTTYPE']._serialized_end=1471
  _globals['_ANONYMOUSACCESSFLAGS']._serialized_start=1474
  _globals['_ANONYMOUSACCESSFLAGS']._serialized_end=1629
  _globals['_CORSRULE']._serialized_start=1632
  _globals['_CORSRULE']._serialized_end=1988
  _globals['_CORSRULE_METHOD']._serialized_start=1871
  _globals['_CORSRULE_METHOD']._serialized_end=1988
  _globals['_WEBSITESETTINGS']._serialized_start=1991
  _globals['_WEBSITESETTINGS']._serialized_end=2819
  _globals['_WEBSITESETTINGS_SCHEME']._serialized_start=2197
  _globals['_WEBSITESETTINGS_SCHEME']._serialized_end=2292
  _globals['_WEBSITESETTINGS_CONDITION']._serialized_start=2294
  _globals['_WEBSITESETTINGS_CONDITION']._serialized_end=2373
  _globals['_WEBSITESETTINGS_REDIRECT']._serialized_start=2376
  _globals['_WEBSITESETTINGS_REDIRECT']._serialized_end=2586
  _globals['_WEBSITESETTINGS_ROUTINGRULE']._serialized_start=2589
  _globals['_WEBSITESETTINGS_ROUTINGRULE']._serialized_end=2742
  _globals['_WEBSITESETTINGS_PROTOCOL']._serialized_start=2744
  _globals['_WEBSITESETTINGS_PROTOCOL']._serialized_end=2819
  _globals['_LIFECYCLERULE']._serialized_start=2822
  _globals['_LIFECYCLERULE']._serialized_end=4587
  _globals['_LIFECYCLERULE_AFTERDAYS']._serialized_start=3485
  _globals['_LIFECYCLERULE_AFTERDAYS']._serialized_end=3556
  _globals['_LIFECYCLERULE_NONCURRENTDELETEMARKERS']._serialized_start=3558
  _globals['_LIFECYCLERULE_NONCURRENTDELETEMARKERS']._serialized_end=3637
  _globals['_LIFECYCLERULE_NONCURRENTEXPIRATION']._serialized_start=3639
  _globals['_LIFECYCLERULE_NONCURRENTEXPIRATION']._serialized_end=3715
  _globals['_LIFECYCLERULE_NONCURRENTTRANSITION']._serialized_start=3717
  _globals['_LIFECYCLERULE_NONCURRENTTRANSITION']._serialized_end=3822
  _globals['_LIFECYCLERULE_TRANSITION']._serialized_start=3825
  _globals['_LIFECYCLERULE_TRANSITION']._serialized_end=3957
  _globals['_LIFECYCLERULE_EXPIRATION']._serialized_start=3960
  _globals['_LIFECYCLERULE_EXPIRATION']._serialized_end=4123
  _globals['_LIFECYCLERULE_RULEFILTER']._serialized_start=4126
  _globals['_LIFECYCLERULE_RULEFILTER']._serialized_end=4587
  _globals['_LIFECYCLERULE_RULEFILTER_AND']._serialized_start=4400
  _globals['_LIFECYCLERULE_RULEFILTER_AND']._serialized_end=4587
  _globals['_COUNTERS']._serialized_start=4590
  _globals['_COUNTERS']._serialized_end=4811
  _globals['_OPTIONALSIZEBYCLASS']._serialized_start=4813
  _globals['_OPTIONALSIZEBYCLASS']._serialized_end=4906
  _globals['_SIZEBYCLASS']._serialized_start=4908
  _globals['_SIZEBYCLASS']._serialized_end=4964
  _globals['_COUNTERSBYCLASS']._serialized_start=4966
  _globals['_COUNTERSBYCLASS']._serialized_end=5059
  _globals['_BUCKETSTATS']._serialized_start=5062
  _globals['_BUCKETSTATS']._serialized_end=5616
  _globals['_HTTPSCONFIG']._serialized_start=5619
  _globals['_HTTPSCONFIG']._serialized_end=6068
  _globals['_HTTPSCONFIG_SOURCETYPE']._serialized_start=5949
  _globals['_HTTPSCONFIG_SOURCETYPE']._serialized_end=6068
  _globals['_OBJECTLOCK']._serialized_start=6071
  _globals['_OBJECTLOCK']._serialized_end=6570
  _globals['_OBJECTLOCK_DEFAULTRETENTION']._serialized_start=6237
  _globals['_OBJECTLOCK_DEFAULTRETENTION']._serialized_end=6449
  _globals['_OBJECTLOCK_DEFAULTRETENTION_MODE']._serialized_start=6363
  _globals['_OBJECTLOCK_DEFAULTRETENTION_MODE']._serialized_end=6433
  _globals['_OBJECTLOCK_OBJECTLOCKSTATUS']._serialized_start=6451
  _globals['_OBJECTLOCK_OBJECTLOCKSTATUS']._serialized_end=6570
  _globals['_ENCRYPTION']._serialized_start=6573
  _globals['_ENCRYPTION']._serialized_end=6720
  _globals['_ENCRYPTION_ENCRYPTIONRULE']._serialized_start=6654
  _globals['_ENCRYPTION_ENCRYPTIONRULE']._serialized_end=6720
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CloudApplication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CloudApplication._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: CloudApplication._Status.ValueType  # 0
        PROCESSING: CloudApplication._Status.ValueType  # 1
        """Application under deploying / updating /deleting"""
        DEPLOYED: CloudApplication._Status.ValueType  # 2
        """Application successfully deployed to YC"""
        FAILED: CloudApplication._Status.ValueType  # 3
        """Application failed to deploy"""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: CloudApplication.Status.ValueType  # 0
    PROCESSING: CloudApplication.Status.ValueType  # 1
    """Application under deploying / updating /deleting"""
    DEPLOYED: CloudApplication.Status.ValueType  # 2
    """Application successfully deployed to YC"""
    FAILED: CloudApplication.Status.ValueType  # 3
    """Application failed to deploy"""

    @typing.final
    class Billing(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _BillingType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _BillingTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CloudApplication.Billing._BillingType.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            BILLING_TYPE_UNSPECIFIED: CloudApplication.Billing._BillingType.ValueType  # 0
            PAY_AS_YOU_GO: CloudApplication.Billing._BillingType.ValueType  # 1
            """User pays for application usage time"""
            SUBSCRIPTION: CloudApplication.Billing._BillingType.ValueType  # 2
            """User bought a subscription"""

        class BillingType(_BillingType, metaclass=_BillingTypeEnumTypeWrapper): ...
        BILLING_TYPE_UNSPECIFIED: CloudApplication.Billing.BillingType.ValueType  # 0
        PAY_AS_YOU_GO: CloudApplication.Billing.BillingType.ValueType  # 1
        """User pays for application usage time"""
        SUBSCRIPTION: CloudApplication.Billing.BillingType.ValueType  # 2
        """User bought a subscription"""

        @typing.final
        class Subscription(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            INSTANCE_ID_FIELD_NUMBER: builtins.int
            TEMPLATE_ID_FIELD_NUMBER: builtins.int
            instance_id: builtins.str
            """Identifier of subscription instance"""
            template_id: builtins.str
            """Subscription template identifier"""
            def __init__(
                self,
                *,
                instance_id: builtins.str = ...,
                template_id: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["instance_id", b"instance_id", "template_id", b"template_id"]) -> None: ...

        TYPE_FIELD_NUMBER: builtins.int
        SUBSCRIPTIONS_FIELD_NUMBER: builtins.int
        type: global___CloudApplication.Billing.BillingType.ValueType
        """Type of application billing"""
        @property
        def subscriptions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudApplication.Billing.Subscription]:
            """Subscriptions bounded to cloud application"""

        def __init__(
            self,
            *,
            type: global___CloudApplication.Billing.BillingType.ValueType = ...,
            subscriptions: collections.abc.Iterable[global___CloudApplication.Billing.Subscription] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["subscriptions", b"subscriptions", "type", b"type"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    BILLING_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Application Identifier"""
    status: global___CloudApplication.Status.ValueType
    """Application Status"""
    @property
    def billing(self) -> global___CloudApplication.Billing:
        """Application billing info"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        status: global___CloudApplication.Status.ValueType = ...,
        billing: global___CloudApplication.Billing | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["billing", b"billing"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["billing", b"billing", "id", b"id", "status", b"status"]) -> None: ...

global___CloudApplication = CloudApplication



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/dataset/v1/dataset.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/ai/dataset/v1/dataset.proto\x12\x1ayandex.cloud.ai.dataset.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xac\x04\n\x0b\x44\x61tasetInfo\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x10\n\x08metadata\x18\x05 \x01(\t\x12>\n\x06status\x18\x06 \x01(\x0e\x32..yandex.cloud.ai.dataset.v1.DatasetInfo.Status\x12\x11\n\ttask_type\x18\x07 \x01(\t\x12.\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04rows\x18\n \x01(\x03\x12\x12\n\nsize_bytes\x18\x0b \x01(\x03\x12\x15\n\rcreated_by_id\x18\x0c \x01(\t\x12\x43\n\x06labels\x18\r \x03(\x0b\x32\x33.yandex.cloud.ai.dataset.v1.DatasetInfo.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"a\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\x0e\n\nVALIDATING\x10\x02\x12\t\n\x05READY\x10\x03\x12\x0b\n\x07INVALID\x10\x04\x12\x0c\n\x08\x44\x45LETING\x10\x05\"P\n\x0fValidationError\x12\r\n\x05\x65rror\x18\x01 \x01(\t\x12\x19\n\x11\x65rror_description\x18\x02 \x01(\t\x12\x13\n\x0brow_numbers\x18\x03 \x03(\x03\x42\x65\n\x1eyandex.cloud.api.ai.dataset.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/dataset/v1;fomob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.dataset.v1.dataset_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036yandex.cloud.api.ai.dataset.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/dataset/v1;fomo'
  _DATASETINFO_LABELSENTRY._options = None
  _DATASETINFO_LABELSENTRY._serialized_options = b'8\001'
  _globals['_DATASETINFO']._serialized_start=106
  _globals['_DATASETINFO']._serialized_end=662
  _globals['_DATASETINFO_LABELSENTRY']._serialized_start=518
  _globals['_DATASETINFO_LABELSENTRY']._serialized_end=563
  _globals['_DATASETINFO_STATUS']._serialized_start=565
  _globals['_DATASETINFO_STATUS']._serialized_end=662
  _globals['_VALIDATIONERROR']._serialized_start=664
  _globals['_VALIDATIONERROR']._serialized_end=744
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/eventrouter/v1/event_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/serverless/eventrouter/v1/event_service.proto\x12&yandex.cloud.serverless.eventrouter.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1dyandex/cloud/validation.proto\"G\n\x0fPutEventRequest\x12\x14\n\x06\x62us_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1e\n\x04\x62ody\x18\x02 \x01(\tB\x10\xe8\xc7\x31\x01\x8a\xc8\x31\x08<=2621442\x97\x01\n\x0c\x45ventService\x12\x86\x01\n\x03Put\x12\x37.yandex.cloud.serverless.eventrouter.v1.PutEventRequest\x1a\x16.google.protobuf.Empty\".\x82\xd3\xe4\x93\x02(\"#/eventrouter/v1/events/{bus_id}:put:\x01*B\x8b\x01\n*yandex.cloud.api.serverless.eventrouter.v1B\x05PERESZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/eventrouter/v1;eventrouterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.eventrouter.v1.event_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*yandex.cloud.api.serverless.eventrouter.v1B\005PERESZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/eventrouter/v1;eventrouter'
  _PUTEVENTREQUEST.fields_by_name['bus_id']._options = None
  _PUTEVENTREQUEST.fields_by_name['bus_id']._serialized_options = b'\350\3071\001'
  _PUTEVENTREQUEST.fields_by_name['body']._options = None
  _PUTEVENTREQUEST.fields_by_name['body']._serialized_options = b'\350\3071\001\212\3101\010<=262144'
  _EVENTSERVICE.methods_by_name['Put']._options = None
  _EVENTSERVICE.methods_by_name['Put']._serialized_options = b'\202\323\344\223\002(\"#/eventrouter/v1/events/{bus_id}:put:\001*'
  _globals['_PUTEVENTREQUEST']._serialized_start=192
  _globals['_PUTEVENTREQUEST']._serialized_end=263
  _globals['_EVENTSERVICE']._serialized_start=266
  _globals['_EVENTSERVICE']._serialized_end=417
# @@protoc_insertion_point(module_scope)
